@@ -29,3 +29,7 @@ class Heroku(object):
         app.config.setdefault('CACHE_MEMCACHED_SERVERS', environ.get('MEMCACHIER_SERVERS'))
         app.config.setdefault('CACHE_MEMCACHED_USERNAME', environ.get('MEMCACHIER_USERNAME'))
         app.config.setdefault('CACHE_MEMCACHED_PASSWORD', environ.get('MEMCACHIER_PASSWORD'))
+
+        # rediscloud
+        app.config.setdefault('BROKER_URL', environ.get('REDISCLOUD_URL'))
+        app.config.setdefault('BROKER_BACKEND', environ.get('REDISCLOUD_URL'))
